@@ -105,9 +105,6 @@ pub struct Options {
     #[serde(default = "default_env_name")]
     pub env_name: String,
 
-    #[serde(default)]
-    pub input_source_map: InputSourceMap,
-
     #[serde(default)]
     pub source_maps: Option<SourceMapsConfig>,
 
@@ -281,7 +278,7 @@ impl Options {
                 .clone()
                 .or(config.source_maps)
                 .unwrap_or(SourceMapsConfig::Bool(false)),
-            input_source_map: self.input_source_map.clone(),
+            input_source_map: self.config.input_source_map.clone(),
         }
     }
 }
@@ -355,6 +352,7 @@ impl Default for Rc {
                 module: None,
                 minify: None,
                 source_maps: None,
+                input_source_map: InputSourceMap::default(),
             },
             Config {
                 env: None,
@@ -374,6 +372,7 @@ impl Default for Rc {
                 module: None,
                 minify: None,
                 source_maps: None,
+                input_source_map: InputSourceMap::default(),
             },
             Config {
                 env: None,
@@ -393,6 +392,7 @@ impl Default for Rc {
                 module: None,
                 minify: None,
                 source_maps: None,
+                input_source_map: InputSourceMap::default(),
             },
         ])
     }
@@ -457,6 +457,9 @@ pub struct Config {
     #[serde(default)]
     pub minify: Option<bool>,
 
+    #[serde(default)]
+    pub input_source_map: InputSourceMap,
+
     /// Possible values are: `'inline'`, `true`, `false`.
     #[serde(default)]
     pub source_maps: Option<SourceMapsConfig>,
